@@ -1,5 +1,6 @@
 var NAVTREEINDEX1 =
 {
+"gphoto2-camera_8h.html#a8fa6903e3bf0ab26edc4e915512aa44f":[2,0,1,1,28],
 "gphoto2-camera_8h.html#a95f595a6d9bfe68d99419a0087363f89":[2,0,1,1,56],
 "gphoto2-camera_8h.html#a969c10fd16501f62f0e3a276d237764a":[2,0,1,1,47],
 "gphoto2-camera_8h.html#aa22be0b9b3018082174d0f7c8ecd2e26":[2,0,1,1,50],
@@ -248,6 +249,5 @@ var NAVTREEINDEX1 =
 "gphoto2-filesys_8h.html#a6ee15bfa0ff8bf74872e13a87e1a4907a7f0cc4ba19d9f92f2e8e12de6580f47b":[2,0,1,4,23,2],
 "gphoto2-filesys_8h.html#a6ee15bfa0ff8bf74872e13a87e1a4907a9277302e076066219975e49bbc574600":[2,0,1,4,23,7],
 "gphoto2-filesys_8h.html#a6ee15bfa0ff8bf74872e13a87e1a4907a9ed3048a35c2f6a59d6e89e52f24b1a5":[2,0,1,4,23,5],
-"gphoto2-filesys_8h.html#a6f6d981b8ab1273e8048df66670782ab":[2,0,1,4,52],
-"gphoto2-filesys_8h.html#a75d0f5c804d7ea9274729202913aa472":[2,0,1,4,11]
+"gphoto2-filesys_8h.html#a6f6d981b8ab1273e8048df66670782ab":[2,0,1,4,52]
 };
