@@ -1,5 +1,6 @@
 var NAVTREEINDEX2 =
 {
+"gphoto2-filesys_8h.html#a75d0f5c804d7ea9274729202913aa472":[2,0,1,4,11],
 "gphoto2-filesys_8h.html#a7bbfa59b2587d36fa5be529c788f9585":[2,0,1,4,37],
 "gphoto2-filesys_8h.html#a7e4db0952402346bf8c8c6a51581efec":[2,0,1,4,17],
 "gphoto2-filesys_8h.html#a7ee1e023cac99c0e96d28954bd626b19":[2,0,1,4,51],
@@ -248,6 +249,5 @@ var NAVTREEINDEX2 =
 "gphoto2-port-result_8h.html#afd4a48ebc75390ed40bdf4b5cc30b258":[2,0,3,0,4,14],
 "gphoto2-port-result_8h_source.html":[2,0,3,0,4],
 "gphoto2-port-version_8c.html":[2,0,3,1,5],
-"gphoto2-port-version_8c.html#a293e53d10075f8c09b39325d8e54be43":[2,0,3,1,5,0],
-"gphoto2-port-version_8h.html":[2,0,3,0,5]
+"gphoto2-port-version_8c.html#a293e53d10075f8c09b39325d8e54be43":[2,0,3,1,5,0]
 };
