@@ -1,5 +1,6 @@
 var NAVTREEINDEX3 =
 {
+"gphoto2-port-version_8h.html":[2,0,3,0,5],
 "gphoto2-port-version_8h.html#a293e53d10075f8c09b39325d8e54be43":[2,0,3,0,5,2],
 "gphoto2-port-version_8h.html#a2b1839ee3cf2ec655565825241206719":[2,0,3,0,5,1],
 "gphoto2-port-version_8h.html#a2b1839ee3cf2ec655565825241206719a4e1b3c861cc4c757d294f356eaf69c82":[2,0,3,0,5,1,1],
@@ -248,6 +249,5 @@ var NAVTREEINDEX3 =
 "jpeg_8c.html#a15c75310906f82a5922655361510dcf5":[2,0,2,20,24],
 "jpeg_8c.html#a2a3b3ac76f7224d6e5f635f1a831e6c7":[2,0,2,20,8],
 "jpeg_8c.html#a2a7832a90410c88f8f4d1f99ff64c461":[2,0,2,20,15],
-"jpeg_8c.html#a2cc14f63e9eb5bac86a036771bfb1758":[2,0,2,20,12],
-"jpeg_8c.html#a30e48d4e0366699fcd210b93a4c6a4f8":[2,0,2,20,26]
+"jpeg_8c.html#a2cc14f63e9eb5bac86a036771bfb1758":[2,0,2,20,12]
 };
